WebSocket Protocols
===================

Gradium provides WebSocket-based streaming protocols for low-latency real-time communication. These protocols enable:

* Real-time text-to-speech with streaming audio output
* Real-time speech-to-text with streaming audio input
* Voice Activity Detection (VAD) for turn-taking
* Bidirectional communication with minimal latency

.. include:: websocket_tts_description.md
   :parser: myst_parser.sphinx_

.. include:: websocket_stt_description.md
   :parser: myst_parser.sphinx_
